==> glib-web-0.2.16.tgz: package/utils/launch.js <==
import Vue from 'vue'
import Dialog from '../nav/dialog'
import Sheet from '../nav/sheet'
import Snackbar from '../nav/snackbar'

export default class {
  static dialog(properties) {
    // https://css-tricks.com/creating-vue-js-component-instances-programmatically/
    const DialogClass = Vue.extend(Dialog)
    const instance = new DialogClass()
    instance.spec = properties

    const placeholder = document.body.appendChild(document.createElement('div'))
    instance.$mount(placeholder)

    // TODO: doesn't work when this method gets called the second time
    // TODO: this assumes there can only be at most one dialog
    // this.dialog = instance
  }

  static closeDialog(properties, target, component) {
    Utils.type.ifObject(this.dialog, dialog => {
      dialog.close()
    })
    this.dialog = null

    Utils.type.ifObject(properties['onClose'], it => {
      Action.execute(it, target, component)
    })
  }

  static sheet(properties) {
    const SheetClass = Vue.extend(Sheet)
    const instance = new SheetClass()
    instance.spec = properties
    const placeholder = document.body.appendChild(document.createElement('div'))
    instance.$mount(placeholder)
    instance.show = true
  }

  static snackbar(properties) {
    const SnackbarClass = Vue.extend(Snackbar)
    const instance = new SnackbarClass()
    instance.spec = properties

    const placeholder = document.body.appendChild(document.createElement('div'))
    instance.$mount(placeholder)
    instance.show = true
  }
}

==> glib-web-0.3.6.tgz: package/utils/launch.js <==
import Vue from 'vue'
import Dialog from '../nav/dialog'
import Sheet from '../nav/sheet'
import Snackbar from '../nav/snackbar'
import Vuetify from 'vuetify'

export default class {
  static dialog(properties) {
    if (!this.stack) {
      this.stack = []
    }

    // https://css-tricks.com/creating-vue-js-component-instances-programmatically/
    const DialogClass = Vue.extend(Dialog)
    const instance = new DialogClass({
      vuetify: new Vuetify(),
      propsData: { spec: properties }
    })
    // instance.spec = properties
    instance.stack = this.stack

    const placeholder = document.body.appendChild(document.createElement('div'))
    instance.$mount(placeholder)
  }

  static closeDialog(properties, target, component) {
    if (!this.stack) {
      this.stack = []
    }

    Utils.type.ifObject(this.stack.last(), dialog => {
      dialog.close()
    })

    Utils.type.ifObject(properties['onClose'], it => {
      Action.execute(it, target, component)
    })
  }

  static sheet(properties) {
    const SheetClass = Vue.extend(Sheet)
    const instance = new SheetClass({
      vuetify: new Vuetify(),
      propsData: { spec: properties }
    })
    // instance.spec = properties
    const placeholder = document.body.appendChild(document.createElement('div'))
    instance.$mount(placeholder)
    instance.show = true
  }

  static snackbar(properties) {
    const SnackbarClass = Vue.extend(Snackbar)
    const instance = new SnackbarClass()
    instance.spec = properties

    const placeholder = document.body.appendChild(document.createElement('div'))
    instance.$mount(placeholder)
    instance.show = true
  }
}
